@@ -1,5 +1,5 @@
 # prime/engine/engine-alphabet.rb
-# $Id: engine-alphabet.rb,v 1.7.4.1 2004/06/01 06:41:28 komatsu Exp $
+# $Id: engine-alphabet.rb,v 1.11 2005/03/07 07:51:32 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -13,6 +13,46 @@ require 'prime/engine/engine'
 $engine_class_name = 'PrimeEngineAlphabet'
 
 class PrimeEngineAlphabet < PrimeEngine
+  @@annotations = {
+    "-"  => "Ⱦѡ֥ޥʥ",
+    "" => "ѡ֥ޥʥ",
+    "" => "Ĺ",
+    "" => "",
+    "" => "֤",
+    "" => "֥å",
+    "" => "֥ϥե",
+    "x"  => "Ⱦѡ֥å",
+    "X"  => "Ⱦѡ֥å",
+    "" => "ѡ֥å",
+    "" => "ѡ֥å",
+    "" => "֤",
+    "o"  => "Ⱦѡ֥",
+    "O"  => "Ⱦѡ֥",
+    "0"  => "Ⱦѡ֥",
+    "" => "ѡ֥",
+    "" => "ѡ֥",
+    "" => "ѡ֥",
+    "" => "֥",
+    "" => "֤ޤ",
+    "" => "֤ޤ2",
+    "" => "ѥ",
+    "" => "֤ˡ",
+    "" => "Ҥ餬",
+    "" => "",
+    "" => "Ҥ餬",
+    "" => "",
+    "" => "",
+    "" => "Ҥ餬",
+    "" => "Ҥ餬",
+    "" => "",
+    "|"  => "Ⱦ",
+    "" => "",
+    "."  => "Ⱦ",
+    "" => "",
+    ","  => "Ⱦ",
+    "" => "",
+  }
+
   def initialize
     super
 
@@ -76,6 +116,13 @@ class PrimeEngineAlphabet < PrimeEngine
                                  "̤θ", 8000) # Ҥ餬ʤʤ
       end
     }
+
+    results.each { | word |
+      if @@annotations.has_key?( word.literal ) and
+          (not word.data.has_key?('form')) then
+        word.data['form'] = @@annotations[ word.literal ]
+      end
+    }
     return results
   end
 end
