@@ -1,5 +1,5 @@
 # prime/engine/engine-personaldict.rb
-# $Id: engine-personaldict.rb,v 1.2 2004/03/25 17:19:50 komatsu Exp $
+# $Id: engine-personaldict.rb,v 1.3 2005/03/07 07:51:32 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -31,19 +31,25 @@ class PrimeEnginePersonalDict < PrimeEngineSary
   def initialize_dict ()
     flag_create = false
 
+    ## @dict_file is defined in the parent class PrimeEngineSary,
+    ## its value should be @dict_dir + '/' + @dict_name.
     if File::exist?(@dict_file) then
       mtime = File::mtime(@dict_file)
-      Dir::foreach(@src_dir) {|src_dict|
-        if src_dict =~ /.dict$/ and 
-            File::mtime(@src_dir + '/' + src_dict) > mtime then
-          flag_create = true
-          break
-        end
-      }
     else
-      flag_create = true
+      ## The below mtime means a sentinel.
+      mtime = Time::at(0)
     end
 
+    Dir::foreach(@src_dir) { | src_dict |
+      ## Matching the filename src_dict with (.dict|.skkdict|.cannadict)
+      ## and comparing the timestamp with the index file.
+      if src_dict =~ /dict$/ and 
+          File::mtime(@src_dir + '/' + src_dict) > mtime then
+        flag_create = true
+        break
+      end
+    }
+
     ## FIXME: Move the following codes to prime-dict-convert.
     ## FIXME: <komatsu@taiyaki.org> (2004-02-06)
     if flag_create then
@@ -72,6 +78,7 @@ class PrimeEnginePersonalDict < PrimeEngineSary
           File::rename(tmp_dir + '/' + file, @dict_dir + '/' + file)
         end
       }
+      ## This might exec the command "prime-refresh".
       system("#{PRIME_COMMAND_REFRESH}")
     end
 
