@@ -1,5 +1,5 @@
 # prime/engine/engine.rb
-# $Id: engine.rb,v 1.1.1.1.2.8 2004/01/26 06:39:40 komatsu Exp $
+# $Id: engine.rb,v 1.3 2004/03/25 17:19:50 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -70,8 +70,14 @@ class PrimeEngine
     return true # of false
   end
 
+  ## update
+  # update the data of the conversion engines.
+  def update
+    return true
+  end
   ## refresh
   # refresh the statuses of the conversion engines.
+  # this is supporsed to be called after update.
   def refresh
     return true
   end
