@@ -1,5 +1,5 @@
 #### prime-userdict.rb: Library for userdict of PRIME.
-#### $Id: basicdict.rb,v 1.1.2.3 2003/12/31 09:26:42 komatsu Exp $
+#### $Id: basicdict.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
 ####
 #### Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ####     All rights reserved.
@@ -14,7 +14,7 @@ require 'prime/makedict/prime-sary' # For PrimeMakeIndex
 
 class PrimeBasicdict < PrimeSaryMakeIndex
   def initialize(dictname, is_interactive = true)
-    super(dictname)
+    super(dictname, is_interactive)
   end
 
   def make_pos_table(is_interactive = @is_interactive)
