@@ -1,5 +1,5 @@
-# dictformat-cannadic.rb: Converter module for cannadic format.
-# $Id: dictformat.rb,v 1.2.4.1 2004/06/01 06:41:27 komatsu Exp $
+# dictformat.rb:
+# $Id: dictformat.rb,v 1.4 2005/03/07 07:51:33 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -90,23 +90,18 @@ class DictFormat
     return [pron, (pos or @pos_unknown), literal, freq, attr].join("\t").strip
   end
 
-  def set_word(pron1, pos1, literal1, freq1 = 0, *attr1)
-    if pron1.empty? or literal1.empty? then
+  def set_word(*word)
+    (pron, pos, literal, freq, *attr) = word
+    freq = (freq.to_i or 0)
+
+    if pron.empty? or literal.empty? then
       return false
     end
 
-    (pron2, pos2, literal2, freq2, *attr2) = get_word(pron1, pos1, literal1)
-    pron = pron1
-    literal = literal1
-    if pos1 and pos2.nil? then 
-      @dict[0].delete(label(pron, nil, literal))
-    end
-    pos = (pos1 or pos2)
-
-    freq = (freq1.to_i or 0)
-    attr = (attr2 + attr1).uniq
-    if pos1 == pos2 or pos1.nil? or pos2.nil? then
-      freq  = [freq, freq2].max
+    existent_word = get_word(pron, pos, literal)
+    if existent_word then
+      word = merge_words(existent_word, word)
+      (pron, pos, literal, freq, *attr) = word
     end
 
     @dict[0][label(pron, pos, literal)] = [pron, pos, literal, freq, *attr]
@@ -116,10 +111,31 @@ class DictFormat
     return true
   end
 
+  def merge_words(existent_word, new_word)
+    (pron,  pos,  literal,  freq,  *attr)  = new_word
+    (pron2, pos2, literal2, freq2, *attr2) = existent_word
+
+    freq  = freq.to_i()
+    freq2 = freq2.to_i()
+
+    if pos and pos2.nil? then 
+      @dict[0].delete(label(pron, nil, literal))
+    end
+    pos = (pos or pos2)
+
+    attr = (attr2 + attr).uniq
+    if pos == pos2 or pos.nil? or pos2.nil? then
+      freq = [freq, freq2].max
+    end
+
+    return [pron, pos, literal, freq, *attr]
+  end
+
   def get_word (pron, pos, literal)
     word = (@dict[0][label(pron, pos, literal)] or
 	    @dict[0][label(pron, @dict[1][label(pron, literal)], literal)] or
-	    [pron, pos, literal, 0])
+            nil)
+#	    [pron, pos, literal, 0])
     return word
   end
 
