@@ -1,5 +1,5 @@
 #### prime-sary.rb: Library for sary on PRIME.
-#### $Id: prime-sary.rb,v 1.2.4.1 2004/06/01 06:41:27 komatsu Exp $
+#### $Id: prime-sary.rb,v 1.6 2005/03/07 07:51:33 komatsu Exp $
 ####
 #### Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ####     All rights reserved.
@@ -74,12 +74,13 @@ class PrimeSaryMakeIndex
       ## FIXME: This checking routine is supposed to be moved an external place
       ## FIXME: <komatsu@taiyaki.org> (2004-02-29)
       if (not File::exist?(filename_index)) or 
-          (File::size(filename_index) == 0) or
-        (File::mtime(filename_index) < File::mtime(filename_dict)) then
+          (File::size(filename_index) == 0 and
+             File::size(filename_dict) > 0 ) or
+          (File::mtime(filename_index) < File::mtime(filename_dict)) then
         offset_list.push(offset)
         filenames_index[offset] = filename_index
         ios_index[offset] = open(filename_index, "w")
-        ios_index[offset].flock(File::LOCK_EX)
+        ios_index[offset].flock(File::LOCK_EX|File::LOCK_NB)
       end
     }
 
