@@ -1,5 +1,5 @@
 # prime/prime-japnese.rb: Japanese module for PRIME.
-# $Id: prime-japanese.rb,v 1.4.4.1 2004/06/01 06:41:28 komatsu Exp $
+# $Id: prime-japanese.rb,v 1.11 2005/03/07 07:51:32 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -36,10 +36,11 @@ module PrimeJapanese
       'ư::' => ['֤::', 'Ǿá֤ʤ::'],
       'ư' => ['Ը', 'Ը', 'Ը', 'Ը', 'ʹԸ', 
 	'йԸ', '޹Ը', 'Ը', 'Ը', '(Ԥ)',
-	'', 'ư', '()'],
+	'', 'ư', '()', '&̾'],
       '' => ['ʽ֤ˡ', 'ʽ֤ǡ', 'ʽ֤',
-	'ʽ֤Ρ', 'ʽ֤', '֤ϡ'],
-      '̾' => ['̾', '()&̾', 'ư&̾'],
+                 'ʽ֤ȡ', 
+	'ʽ֤Ρ', 'ʽ֤', '֤ϡ', '³֤ȡ'],
+      '̾' => ['̾', '()&̾', 'ư&̾', '&̾'],
     }
 
     @pos_alias_reverse = {}
@@ -56,11 +57,11 @@ module PrimeJapanese
     @pos_connection_table = {
       '' => [''],
       'Ƭ' => ['̾'],
-      '̾'   => ['', 'ư첽', '̾'],
+      '̾'   => ['', 'ư첽', '̾', 'ƻ', 'ư'],
 
-      '̾&̾'   => ['', 'ư첽'],
-      '̾'        => ['', 'ư첽'],
+      '̾&̾'   => ['̾', '', 'ư첽'],
       '̾'        => ['', 'ư첽'],
+      '̾'        => ['̾', '', 'ư첽'],
 
       ## FIXME: ϡֽߡפǤϤʤϢΡ
       ## FIXME: <komatsu@taiyaki.org> (2004-01-19)
@@ -71,7 +72,7 @@ module PrimeJapanese
       'ư::Ϣi' => ['ư'],
       '' => ['ƻ', 'ư', 'ư&̾', 'ư'],
       'ƻ::Ϣ'   => ['̾', '̾&̾', '̾', '̾'],
-      'ƻ::Ϣku' => ['ƻ'],
+      'ƻ::Ϣku' => ['ƻ', 'ư'],
       'ư::Ϣ' => ['̾', '̾&̾', '̾', '̾'],
       'ư' => ['̾', '̾&̾', '̾', '̾'],
       '֤::Ϣde' => ['ư'],
@@ -89,6 +90,8 @@ module PrimeJapanese
 #      "֤::\t̾" => 0.9,
 #      "Ǿá֤ʤ::\t̾" => 0.9,
       "\t"  => 0.9,
+      "̾&̾\t̾" => 0.99,
+      "̾\t̾" => 0.99,
       "̾&̾\t=" => 0.99,
       "̾\t="      => 0.99,
       "=\t̾"   => 0.99,
@@ -99,6 +102,14 @@ module PrimeJapanese
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
       "=ɤ\t̾" => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=ɤ\t()&̾"   => 0.99,
+      "=\t()&̾" => 0.99,
+      "=\t()&̾" => 0.99,
+      "=\t()&̾" => 0.99,
+      "=ɤ\t()&̾" => 0.99,
     }
     @pos_connection_cost_default = 0.8
     @pos_connection_pos = {
@@ -108,9 +119,11 @@ module PrimeJapanese
       "\t" => '̾',
       "̾\t" => '̾',
       "̾\tư첽" => 'ư',
-      "̾&̾\t" => '̾',
+      "̾&̾\t̾" => '̾',
+      "̾&̾\t"   => '̾',
       "̾&̾\tư첽" => 'ư',
-      "̾\t" => '̾',
+      "̾\t̾" => '̾',
+      "̾\t"   => '̾',
       "̾\tư첽" => 'ư',
       "̾\t" => '̾',
       "̾\tư첽" => 'ư',
@@ -222,12 +235,46 @@ module PrimeJapanese
           end
           results.push(word)
         end
-       end
+      end
     }
 
     return results
   end
 
+  def search_japanese_uniclause (string)
+    # EXPERIMENTAL CODE
+    string = PrimeTypeConv::convert(string).join
+
+    results = search_raw(string)
+    rest = nil
+
+    clauses_list = process_clauses(string, 1)
+    clauses_list.each {|clauses|
+      if clauses.length == 1 then
+        ## FIXME: It's an adhoc routine.
+        ## FIXME: <komatsu@taiyaki.org> (2004-01-26)
+        (pron, pos, conjugation, conjugation_pos) = clauses.first
+        query = PrimeQuery.new([pron], pos)
+        words = search(query)
+        words.each {|word|
+          word.conjugation = conjugation
+        }
+        results += words
+      end
+    }
+
+    return results
+  end
+  def search_japanese_prefix (string)
+    # EXPERIMENTAL CODE
+    words = PrimeWordList.new()
+    PrimeTypeConv::expand(string).each {|expanded_string|
+      words.push(search_japanese_uniclause(expanded_string))
+#      words.push(search_japanese(expanded_string))
+    }
+    return words
+  end
+
   def get_pos_data (string)
     #| pos_data = {'pron1' => {'pos1-1' => [engine1-1-1, engine1-1-2, ...]
     #|                         'pos1-2' => [engine1-2-1, ...], ...},
@@ -249,8 +296,8 @@ module PrimeJapanese
   ## FIXME: ʸڤ꤬ƱΤ礷
   ## FIXME: <komatsu@taiyaki.org> (2004-01-24)
 
-  def process_clauses (string)
-    (depth, clauses_list) = guess_clauses_internal(string)
+  def process_clauses (string, threshold = 4)
+    (depth, clauses_list) = guess_clauses_internal(string, 1, nil, threshold)
     processed_clauses_list = []
     clauses_list.each {|clauses|
       if clauses.length <= depth then
@@ -354,7 +401,7 @@ class PrimeTypeConv
         PRIME_ENV['typing_method'] == nil then
       if conversion =~ /[a-zA-Z]/ then
         return [string]
-      elsif string =~ /^[0-9+-][0-9,.+-]*/ then
+      elsif string =~ /^-?[0-9+][0-9,.+-]*/ then
         numeral = $&
         string = string[numeral.length..-1]
         (conversion, pending, node) = suikyo.convert_internal(string)
